<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<!-- ==========================================================================

Licensed Materials-Property of IBM

(C)Copyright IBM Corp 2004

All rights reserved

US Government Users Restricted Rights
Use, duplication, or disclosure restricted
by GSA ADP Schedule Contract with IBM Corp


code/catalog/util/src/com/ibm/events/catalog/util/eventDefinitions.xsl, cei_catalog, cei_5.1.0, 200403152330
@Version 1.2 3/15/04

===============================================================================

This stylesheet is used to output a list of event definitions in
human-readable format.

This stylesheet operates on an XML document conforming to the XML schema
eventdefinition.xsd.

Predefined strings such as the title, section headings and field labels are
passed in as parameters.  This allows them to be localized.

========================================================================== -->

<xsl:output method="text" omit-xml-declaration="yes"/>


<!-- ==========================================================================
Parameters for each of the predefined strings used throughout the stylesheet.
The strings are localized by the calling program.
These parameters must correspond one-one with resources in 
CeiCatalogResources.properties.
=========================================================================== -->

<xsl:param name="title_text"/>
<xsl:param name="separator_text"/>
<xsl:param name="name_text"/>
<xsl:param name="parent_text"/>
<xsl:param name="no_parent_text"/>
<xsl:param name="property_title_text"/>
<xsl:param name="property_name_text"/>
<xsl:param name="property_path_text"/>
<xsl:param name="property_required_text"/>
<xsl:param name="property_default_value_text"/>
<xsl:param name="property_permitted_value_text"/>
<xsl:param name="property_permitted_values_text"/>
<xsl:param name="property_minimum_value_text"/>
<xsl:param name="property_maximum_value_text"/>
<xsl:param name="extended_data_element_title_text"/>
<xsl:param name="extended_data_element_name_text"/>
<xsl:param name="extended_data_element_type_text"/>
<xsl:param name="extended_data_element_cardinality_text"/>
<xsl:param name="extended_data_element_default_value_text"/>
<xsl:param name="extended_data_element_default_values_text"/>
<xsl:param name="extended_data_element_default_hex_value_text"/>


<!-- ==========================================================================
A template that matches the top-level eventDefinitionList element.
It outputs a header and then applies the template for any
event definitions contained within it.
=========================================================================== -->

<xsl:template match="*[local-name()='eventDefinitionList']">
<xsl:value-of select="$title_text"/>
<xsl:text>

</xsl:text>
<xsl:apply-templates select="eventDefinition"/>
</xsl:template>


<!-- ==========================================================================
A template that matches an eventDefinition element.
It outputs the fields of the event definition and then
applies the templates for any properties or
extended data elements contained within it.
=========================================================================== -->

<xsl:template match="eventDefinition">
<xsl:value-of select="$separator_text"/><xsl:text>
</xsl:text><xsl:value-of select="$name_text"/>:  <xsl:value-of select="@name" /><xsl:text>
</xsl:text><xsl:value-of select="$parent_text"/>:  <xsl:choose>
           <xsl:when test="string-length(@parent)=0"><xsl:value-of select="$no_parent_text"/></xsl:when>
           <xsl:otherwise>
             <xsl:value-of select="@parent"/>
           </xsl:otherwise>
         </xsl:choose>
<xsl:text>

</xsl:text>
<xsl:apply-templates select="property"/>
<xsl:apply-templates select="extendedDataElement"/>
</xsl:template>


<!-- ==========================================================================
A template that matches a property element.
It outputs the fields of the property.
=========================================================================== -->

<xsl:template match="property">

<xsl:value-of select="$property_title_text"/><xsl:text>
    </xsl:text><xsl:value-of select="$property_name_text"/>:  <xsl:value-of select="@name" /><xsl:text>
    </xsl:text><xsl:value-of select="$property_path_text"/>:  <xsl:value-of select="@path" /><xsl:text>
    </xsl:text><xsl:value-of select="$property_required_text"/>:  <xsl:value-of select="@required" /><xsl:text>
</xsl:text>
<xsl:if test="string-length(defaultValue)!=0">
<xsl:text>    </xsl:text><xsl:value-of select="$property_default_value_text"/>:  <xsl:value-of select="defaultValue" /><xsl:text>
</xsl:text>
</xsl:if>
<xsl:choose>
  <xsl:when test="count(permittedValue)=1">
    <xsl:text>    </xsl:text><xsl:value-of select="$property_permitted_value_text"/>:  </xsl:when>
  <xsl:when test="count(permittedValue)>1">
    <xsl:text>    </xsl:text><xsl:value-of select="$property_permitted_values_text"/>:  </xsl:when>
</xsl:choose>
<xsl:for-each select="permittedValue">
  <xsl:value-of select="." />
  <xsl:if test="position()!=last()">, </xsl:if>
  <xsl:if test="position()=last()"><xsl:text>
</xsl:text></xsl:if>
</xsl:for-each>
<xsl:if test="string-length(minValue)!=0">
    <xsl:text>    </xsl:text><xsl:value-of select="$property_minimum_value_text"/>:  <xsl:value-of select="minValue" /><xsl:text>
</xsl:text>
</xsl:if>
<xsl:if test="string-length(maxValue)!=0">
    <xsl:text>    </xsl:text><xsl:value-of select="$property_maximum_value_text"/>:  <xsl:value-of select="maxValue" /><xsl:text>
</xsl:text>
</xsl:if>
<xsl:text>
</xsl:text>
</xsl:template>


<!-- ==========================================================================
A template that matches an extendedDataElement element.
It outputs the fields of the extended data element
and then recurses into any nested extended data elements.
=========================================================================== -->

<xsl:template match="extendedDataElement">

<!--
    Indicate nesting of extended data elements by indenting them with a
    string of blanks.  
    The length of the string is proportional to the depth of nesting.
-->

<xsl:variable name="indent">
<xsl:for-each select="../../ancestor::*">
<xsl:text>    </xsl:text>
</xsl:for-each>
</xsl:variable>

<xsl:copy-of select="$indent" /><xsl:value-of select="$extended_data_element_title_text"/><xsl:text>
    </xsl:text><xsl:copy-of select="$indent" />    <xsl:value-of select="$extended_data_element_name_text"/>:  <xsl:value-of select="@name" /><xsl:text>
    </xsl:text><xsl:copy-of select="$indent" />    <xsl:value-of select="$extended_data_element_type_text"/>:  <xsl:value-of select="@type" /><xsl:text>
    </xsl:text><xsl:copy-of select="$indent" />    <xsl:value-of select="$extended_data_element_cardinality_text"/>:  <xsl:value-of select="@minOccurs" /><xsl:if test="@minOccurs!=@maxOccurs">-<xsl:value-of select="@maxOccurs" /></xsl:if><xsl:text>
    </xsl:text>
<xsl:choose>
  <xsl:when test="count(defaultValue)=1">
<xsl:copy-of select="$indent" />    <xsl:value-of select="$extended_data_element_default_value_text"/>:  </xsl:when>
  <xsl:when test="count(defaultValue)>1">
<xsl:copy-of select="$indent" />    <xsl:value-of select="$extended_data_element_default_values_text"/>:  </xsl:when>
</xsl:choose>
<xsl:for-each select="defaultValue">
  <xsl:value-of select="." />
  <xsl:if test="position()!=last()">, </xsl:if>
  <xsl:if test="position()=last()"><xsl:text>
</xsl:text></xsl:if>
</xsl:for-each>
<xsl:if test="string-length(defaultHexValue)!=0">
<xsl:copy-of select="$indent" />    <xsl:value-of select="$extended_data_element_default_hex_value_text"/>:  <xsl:value-of select="defaultHexValue" /><xsl:text>
</xsl:text>
</xsl:if>
<xsl:text>
</xsl:text>
<xsl:apply-templates select="extendedDataElement"/>
</xsl:template>

</xsl:stylesheet>
